@@ -1,5 +1,5 @@
 # flake8:noqa
-from . import demos
+from . import demos, update_checker
 from .label_maker import LabelMaker
 from .label_times import LabelTimes, read_label_times
 from .version import __version__
